pyxmpp2.transport.ContinueConnect

Package pyxmpp2 :: Module transport :: Class ContinueConnect |
[hide private]

# Class ContinueConnect

Object to signal (via the write queue) a pending connect request.

Instance Methods | [hide private]
Inherited from `WriteJob`: `__repr__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`